from setuptools import setup

setup(
    name='pyccr',
    version='0.0.1',
    description='Contextualized Construct Representations (CCR).',
    long_description='',
    url='https://github.com/Ali-Omrani',
    author='Ali Omrani',
    author_email='aomrani@usc.edu',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)